'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _label = require('./label.css');

var _label2 = _interopRequireDefault(_label);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Label = function Label(props) {
  var min = props.min,
      icon = props.icon,
      text = props.text,
      color = props.color,
      theme = props.theme,
      active = props.active,
      onClick = props.onClick,
      onDelete = props.onDelete,
      disabled = props.disabled,
      clickable = props.clickable,
      className = props.className,
      deleteable = props.deleteable,
      _props$style = props.style,
      style = _props$style === undefined ? {} : _props$style;


  var iconElement = typeof icon === 'string' ? _react2.default.createElement('i', { className: 'fa fa-' + icon, 'aria-hidden': 'true' }) : icon;

  var handleClick = function handleClick() {
    if (!clickable || disabled) return;
    onClick && onClick(text);
  };
  var handleDelete = function handleDelete() {
    if (!deleteable || disabled) return;
    onDelete && onDelete(text);
  };

  return _react2.default.createElement(
    'div',
    {
      style: style,
      className: (0, _classnames2.default)(_label2.default.label, _label2.default[color], _label2.default[theme], min && _label2.default.min, deleteable && _label2.default.deleteable, disabled && _label2.default.disabled, clickable && _label2.default.clickable, active && _label2.default.active, className)
    },
    _react2.default.createElement(
      'div',
      { className: _label2.default.labelWrapper },
      !disabled && deleteable && _react2.default.createElement(
        'div',
        {
          onClick: handleDelete,
          className: _label2.default.labelDelete
        },
        'x'
      ),
      _react2.default.createElement(
        'div',
        {
          onClick: handleClick,
          className: (0, _classnames2.default)(_label2.default.labelContent, !disabled && clickable && _label2.default.clickable, disabled && _label2.default.disabled) },
        iconElement,
        _react2.default.createElement(
          'span',
          {
            className: (0, _classnames2.default)(_label2.default.labelText, iconElement && _label2.default.withIcon)
          },
          text
        )
      )
    )
  );
};

Label.propTypes = {
  text: _propTypes2.default.string,
  min: _propTypes2.default.bool,
  active: _propTypes2.default.bool,
  clickable: _propTypes2.default.bool,
  deleteable: _propTypes2.default.bool,
  disabled: _propTypes2.default.bool,
  onClick: _propTypes2.default.func,
  onDelete: _propTypes2.default.func,
  className: _propTypes2.default.string,
  theme: _propTypes2.default.string,
  icon: _propTypes2.default.oneOfType([_propTypes2.default.node, _propTypes2.default.string]),
  color: _propTypes2.default.string
};

Label.defaultProps = {
  text: '',
  min: false,
  active: true,
  clickable: true,
  onClick: Function.prototype,
  className: '',
  theme: 'material',
  icon: null,
  onDelete: Function.prototype,
  deleteable: false,
  disabled: false,
  color: 'dark'
};

exports.default = Label;